@@ -28,7 +28,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.4.6"
+__version__ = "1.5.0"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -828,6 +828,8 @@ def _poetry2pipfile_lock(
                 # Otherwise, configure it explicitly.
                 if len(sources) > 1:
                     requirement["index"] = entry["source"]["reference"]
+            elif entry["source"]["type"] == "url":
+                requirement["file"] = entry["source"]["url"]
             else:
                 raise NotSupportedError(
                     "micropipenv supports Git VCS or directories, got {} instead".format(entry["source"]["type"])
